@@ -9,12 +9,12 @@
         <translation>Hilfe</translation>
     </message>
     <message>
-        <location filename="helpwindow.cpp" line="56"/>
+        <location filename="helpwindow.cpp" line="74"/>
         <source>QCPUFreq</source>
         <translation>QCPUFreq</translation>
     </message>
     <message>
-        <location filename="helpwindow.cpp" line="56"/>
+        <location filename="helpwindow.cpp" line="74"/>
         <source>Cannot open help file!</source>
         <translation>Kann die Hilfe-Datei nicht öffnen!</translation>
     </message>
@@ -23,8 +23,8 @@
     <name>MainWindow</name>
     <message>
         <location filename="mainwindow.ui" line="14"/>
-        <location filename="mainwindow.cpp" line="162"/>
-        <location filename="mainwindow.cpp" line="337"/>
+        <location filename="mainwindow.cpp" line="187"/>
+        <location filename="mainwindow.cpp" line="379"/>
         <source>QCPUFreq</source>
         <translation>QCPUFreq</translation>
     </message>
@@ -38,8 +38,8 @@
         <location filename="mainwindow.ui" line="67"/>
         <location filename="mainwindow.ui" line="87"/>
         <location filename="mainwindow.ui" line="107"/>
-        <location filename="mainwindow.cpp" line="190"/>
-        <location filename="mainwindow.cpp" line="199"/>
+        <location filename="mainwindow.cpp" line="215"/>
+        <location filename="mainwindow.cpp" line="224"/>
         <source>Unknown</source>
         <translation>Unbekannt</translation>
     </message>
@@ -80,44 +80,98 @@
         <translation>Datei</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="374"/>
+        <location filename="mainwindow.ui" line="375"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="379"/>
+        <location filename="mainwindow.ui" line="380"/>
         <source>Help</source>
         <translation>Hilfe</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="387"/>
+        <location filename="mainwindow.ui" line="388"/>
         <source>Enable overclocking</source>
         <translation>Aktiviere Übertakten</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="124"/>
-        <source>You need to enable overclocking in QCPUFreq&apos;s menu for setting frequencies above 600MHz!</source>
-        <translation>Um Frequenzen über 600MHz freizuschalten, muss Overclocking im QCPUFreq Menü aktiviert werden!</translation>
+        <location filename="mainwindow.ui" line="393"/>
+        <source>Settings</source>
+        <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="162"/>
+        <location filename="mainwindow.ui" line="401"/>
+        <source>Save</source>
+        <translation>Speichern</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="130"/>
+        <source>You need to enable overclocking in QCPUFreq&apos;s settings in order to set frequencies above 600MHz!</source>
+        <translation>Um Frequenzen über 600MHz freizuschalten, müssen Sie Übertakten in den QCPUFreq Einstellungen aktivieren!</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="187"/>
         <source>There seems to be a problem with your sudo setup!</source>
         <translation>Es liegt offenbar ein Problem bei der sudo Einrichtung vor!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="337"/>
+        <location filename="mainwindow.cpp" line="379"/>
         <source>Could not get information from /sys!</source>
         <translation>Konnte Informationen aus /sys nicht lesen!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="440"/>
-        <source>Please note that overclocking voids your warranty and may break your device! Be careful!</source>
-        <translation>Bitte beachten Sie, dass Overclocking zu Garantieverlust führt und das Gerät beschädigen kann! Seien Sie vorsichtig!</translation>
+        <location filename="mainwindow.cpp" line="469"/>
+        <source>The current frequency settings have been saved as default.</source>
+        <translation>Die aktuellen Frequenzeinstellungen wurden als Standardeinstellungen gespeichert.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="459"/>
+        <location filename="mainwindow.cpp" line="507"/>
         <source>SmartReflex support is known to be unstable on some devices and may cause random reboots.</source>
         <translation>SmartReflex kann auf einigen Geräten instabil sein und zu zufälligen Neustarts führen.</translation>
     </message>
 </context>
+<context>
+    <name>Settings</name>
+    <message>
+        <location filename="settings.ui" line="14"/>
+        <source>Settings</source>
+        <translation>Einstellungen</translation>
+    </message>
+    <message>
+        <location filename="settings.ui" line="25"/>
+        <source>Enable overclocking</source>
+        <translation>Aktiviere Übertakten</translation>
+    </message>
+    <message>
+        <location filename="settings.ui" line="32"/>
+        <source>Enable auto-rotation</source>
+        <translation>Aktiviere automatisches Drehen</translation>
+    </message>
+    <message>
+        <location filename="settings.ui" line="39"/>
+        <source>Load bq27x00_battery module</source>
+        <translation>Lade bq27x00_battery-Modul</translation>
+    </message>
+    <message>
+        <location filename="settings.cpp" line="52"/>
+        <source>QCPUFreq</source>
+        <translation>QCPUFreq</translation>
+    </message>
+    <message>
+        <location filename="settings.cpp" line="52"/>
+        <source>Could not get information from /sys!</source>
+        <translation>Konnte Informationen aus /sys nicht lesen!</translation>
+    </message>
+    <message>
+        <location filename="settings.cpp" line="144"/>
+        <location filename="settings.cpp" line="146"/>
+        <source>Please note that overclocking voids your warranty and may break your device! Be careful!</source>
+        <translation>Bitte beachten Sie, dass Overclocking zu Garantieverlust führt und das Gerät beschädigen kann! Seien Sie vorsichtig!</translation>
+    </message>
+    <message>
+        <location filename="settings.cpp" line="146"/>
+        <source>Warning</source>
+        <translation>Warnung</translation>
+    </message>
+</context>
 </TS>
