@@ -23,27 +23,15 @@
 #include <QLocale>
 #include <QTextStream>
 #include <QMessageBox>
-#include <QPalette>
-#include <QBrush>
-#include <QColor>
+
 
 HelpWindow::HelpWindow(QWidget *parent) :
     QWidget(parent),
     ui(new Ui::HelpWindow)
 {
-    //this is a stacked window on Maemo 5
-    #if defined(Q_WS_MAEMO_5)
-	//setAttribute(Qt::WA_Maemo5StackedWindow);
-    #endif
     ui->setupUi(this);
 
     setHelpText();
-
-    //format color of help text according to system color scheme
-    QPalette palette;
-    QBrush brush = palette.windowText();
-    QColor color = brush.color();
-    ui->textBrowser->setStyleSheet( "QTextEdit {background: transparent; color: " + color.name() + ";}" );
 }
 
 
