@@ -28,7 +28,7 @@
 #endif
 
 #define APPNAME "QCPUFreq"
-#define APPVERSION "0.4.0"
+#define APPVERSION "0.4.1"
 
 
 MainWindow::MainWindow(QWidget *parent) :
@@ -181,7 +181,7 @@ int MainWindow::callHelper(QString action, QString param)
 
     helperProcess.start( "sudo", arguments, QIODevice::NotOpen );
 
-    if ( showSudoError && !helperProcess.waitForFinished( 400 )) {
+    if ( showSudoError && !helperProcess.waitForFinished( 2000 )) {
         //do not show this error again
         showSudoError = false;
         QMessageBox::critical(this, tr("QCPUFreq"), tr("There seems to be a problem with your sudo setup!"));
@@ -359,7 +359,12 @@ void MainWindow::init()
 
     //enable save option on power kernels
     if (settings->usePowerKernel()) {
-        ui->actionSave->setEnabled(true);
+        //only enable save if /usr/sbin/kernel-config is present
+        file.close();
+        file.setFileName("/usr/sbin/kernel-config");
+        if (file.exists()) {
+            ui->actionSave->setEnabled(true);
+        }
     }
 }
 
@@ -490,6 +495,7 @@ void MainWindow::setAutoRotation()
 {
 #if defined(Q_WS_MAEMO_5)
     setAttribute(Qt::WA_Maemo5AutoOrientation, settings->useAutoRotate());
+    settings->setAttribute(Qt::WA_Maemo5AutoOrientation, settings->useAutoRotate());
 #endif
 }
 
