@@ -1,6 +1,6 @@
 /*
  * QCPUFreq - a simple cpufreq GUI
- * Copyright (C) 2010 Daniel Klaffenbach <daniel.klaffenbach@cs.tu-chemnitz.de>
+ * Copyright (C) 2010 Daniel Klaffenbach <danielklaffenbach@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include <QStringList>
 
 #include "helpwindow.h"
+#include "settings.h"
 
 namespace Ui {
     class MainWindow;
@@ -42,17 +43,19 @@ public:
 public slots:
     void about();
     void adjustFreq();
+    void applySettings();
     void orientationChanged();
     void refresh();
+    void save();
+    void setAdvancedTemperature();
     void setAutoRotation();
-    void setOverclocking();
     void setSmartReflex();
     void showHelp();
+    void showSettings();
 
 
 private:
     Ui::MainWindow *ui;
-    bool allowOverclocking;
     int callHelper( QString action, QString param );
     QString getCPUTemp();
     int getMaxFreq();
@@ -69,8 +72,6 @@ private:
     //! Initializes the application
     void init();
     int minFreq;
-    //! Are we using a power kernel?
-    bool powerKernel;
     QString readSysFile( QString sys_file );
     //! the timer for refreshing the UI
     QTimer refreshTimer;
@@ -81,6 +82,7 @@ private:
     //! the QGraphicsScene will contain the large chip icon displayed in the UI
     QGraphicsScene scene;
     bool showSudoError;
+    Settings *settings;
     bool usePortrait();
 };
 
